@@ -35,11 +35,16 @@ def set_verbosity(ctx, param, value):
     coloredlogs.set_level(logging.INFO - (value * 10))
 
 
+UDID_ENV_VAR = 'PYMOBILEDEVICE3_UDID'
+
+
 class Command(click.Command):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.params[:0] = [
-            click.Option(('lockdown', '--udid'), callback=self.udid),
+            click.Option(('lockdown', '--udid'), envvar=UDID_ENV_VAR, callback=self.udid,
+                         help=f'Device unique identifier. You may pass {UDID_ENV_VAR} environment variable to pass this'
+                              f' option as well'),
             click.Option(('verbosity', '-v', '--verbose'), count=True, callback=set_verbosity, expose_value=False),
         ]
 
