@@ -346,11 +346,19 @@ IRECV_DEVICES = (
                 display_name='Apple Watch Series 7 (45mm Cellular)'),
     # Apple Silicon Macs
     IRecvDevice(product_type='ADP3,2', hardware_model='j273aap', board_id=0x42, chip_id=0x8027,
-                display_name='Developer Transition Kit'),
+                display_name='Developer Transition Kit (2020)'),
     IRecvDevice(product_type='Macmini9,1', hardware_model='j274ap', board_id=0x22, chip_id=0x8103,
                 display_name='Mac mini (M1, 2020)'),
     IRecvDevice(product_type='MacBookPro17,1', hardware_model='j293ap', board_id=0x24, chip_id=0x8103,
                 display_name='MacBook Pro (M1, 2020)'),
+    IRecvDevice(product_type='MacBookPro18,1', hardware_model='j316sap', board_id=0x0A, chip_id=0x6000,
+                display_name='MacBook Pro (M1 Pro, 16-inch, 2021)'),
+    IRecvDevice(product_type='MacBookPro18,2', hardware_model='j316cap', board_id=0x0A, chip_id=0x6001,
+                display_name='MacBook Pro (M1 Max, 16-inch, 2021)'),
+    IRecvDevice(product_type='MacBookPro18,3', hardware_model='j314sap', board_id=0x08, chip_id=0x6000,
+                display_name='MacBook Pro (M1 Pro, 14-inch, 2021)'),
+    IRecvDevice(product_type='MacBookPro18,4', hardware_model='j314cap', board_id=0x08, chip_id=0x6001,
+                display_name='MacBook Pro (M1 Max, 14-inch, 2021)'),
     IRecvDevice(product_type='MacBookAir10,1', hardware_model='j313ap', board_id=0x26, chip_id=0x8103,
                 display_name='MacBook Air (M1, 2020)'),
     IRecvDevice(product_type='iMac21,1', hardware_model='j456ap', board_id=0x28, chip_id=0x8103,
